//******************************************************************************
//
//	File:		SerialPort.h
//
//	Description:	Serial Port class header.
//	
//	Copyright 1995-97, Be Incorporated, All Rights Reserved.
//
//******************************************************************************

#ifndef	_SERIAL_H
#define	_SERIAL_H

#include <OS.h> /* import B_INFINITE_TIMEOUT */

enum data_rate { B_0_BPS = 0, B_50_BPS, B_75_BPS, B_110_BPS, B_134_BPS,
				 B_150_BPS, B_200_BPS, B_300_BPS, B_600_BPS, B_1200_BPS,
				 B_1800_BPS, B_2400_BPS, B_4800_BPS, B_9600_BPS, B_19200_BPS,
				 B_38400_BPS, B_57600_BPS, B_115200_BPS, 
				 B_230400_BPS };

enum data_bits { B_DATA_BITS_7, B_DATA_BITS_8 };

enum stop_bits { B_STOP_BITS_1, B_STOP_BITS_2 };

enum parity_mode { B_NO_PARITY, B_ODD_PARITY, B_EVEN_PARITY };

enum { B_NOFLOW_CONTROL = 0, B_HARDWARE_CONTROL = 0x00000001, 
								B_SOFTWARE_CONTROL = 0x00000002 };

// -----------------------------------------------------------------------
typedef struct 
{
int				ffd;
data_rate		fBaudRate;
data_bits		fDataBits;
stop_bits		fStopBits;
parity_mode		fParityMode;
ulong			fFlow;
uchar			fTimeout;
bool			fBlocking;

} serial_port;



/* Creation and Destruction of Serial port objects */
status_t CreateSerialPort(serial_port **aPort);
void	DestroySerialPort(serial_port *aPort);

/*
** All the generic calls
*/

long			SP_Open(serial_port &, const char *portName);
void			SP_Close(serial_port &);

long			SP_Read(serial_port &, void *buf, size_t count);
long			SP_Write(serial_port &, const void *buf, size_t count);
void			SP_SetBlocking(serial_port &, bool Blocking);
status_t		SP_SetTimeout(serial_port &, bigtime_t microSeconds);

status_t		SP_SetDataRate(serial_port &, data_rate bitsPerSecond);
data_rate		SP_DataRate(serial_port &);

void			SP_SetDataBits(serial_port &, data_bits numBits);
data_bits		SP_DataBits(serial_port &);
void			SP_SetStopBits(serial_port &, stop_bits numBits);
stop_bits		SP_StopBits(serial_port &);

void			SP_SetParityMode(serial_port &, parity_mode which);
parity_mode		SP_ParityMode(serial_port &);

void			SP_ClearInput(serial_port &);
void			SP_ClearOutput(serial_port &);

void			SP_SetFlowControl(serial_port &, ulong method);
ulong			SP_FlowControl(serial_port &);

long			SP_SetDTR(serial_port &, bool asserted);
long			SP_SetRTS(serial_port &, bool asserted);

bool			SP_IsCTS(serial_port &);
bool			SP_IsDSR(serial_port &);
bool			SP_IsRI(serial_port &);
bool			SP_IsDCD(serial_port &);

ssize_t			SP_WaitForInput(serial_port &);

int				SP_DriverControl(serial_port &);

#endif
